function ViewFrame() {
	// dom stuff
	const map = document.createElement('canvas'); // the map we see
	map.className = 'map';
	map.windowHeight = window.innerHeight;
	map.windowWidth = window.innerWidth;
	document.getElementsByTagName('body')[0].append(map);
	// this is the map that we actually draw on
	this.map = map.getContext('2d', {
		alpha: false
	});
	this.map.imageSmoothingEnabled = false;
	// the infoboxes... duh.
	this.infoboxSlots = ViewFrame.initBox('Chunk Info', 'info', ViewFrame.chunks.chunkMetadataNames);
	this.entityInfoSlots = ViewFrame.initBox('Entity Info', 'info', ViewFrame.chunks.entityOfInterestNames);
	this.pointsInfoSlots = ViewFrame.initBox('Point Info', 'info', ViewFrame.chunks.pointsOfInterestNames);

	// ViewFrame.initControlBox();

	// to speed up going over areas we have already been
	this.chunkCache = new Map();
	// so that we dont render twice at the same time
	this.rendering = false;

	this.x = ViewFrame.chunks.startCoords[0];
	this.y = ViewFrame.chunks.startCoords[1];
	this.availableChunks = ViewFrame.chunks.chunkMetadata;
	this.chunkSize = ViewFrame.chunks.chunkSize;

	this.zoom = 32; // pixels wide the shards are to be

	this.updateEdges();
	this.render();
}
// prototypes, some less... notable? methods are
// in ViewFrameUtils.js 
ViewFrame.prototype.reloadChunkList = function (render = false) {
	if (this.chunkScript) {
		this.chunkScript.remove();
		delete this.chunkScript;
	}

	this.chunkScript = document.createElement('script');
	this.chunkScript.type = 'text/javascript';
	this.chunkScript.src = 'Metadata.js';
	document.getElementsByTagName('body')[0].append(this.chunkScript);

	this.chunkScript.addEventListener('load', () => {
		this.availableChunks = ViewFrame.chunks.chunkMetadata;
		this.pointsOfInterest = ViewFrame.chunks.pointsOfInterest;
		if (render) this.render();
	});
};

ViewFrame.prototype.render = function () {
	if (!this.availableChunks) return;
	if (this.rendering) clearInterval(ViewFrame.intervalRef);
	this.rendering = true;
	this.updateEdges();
	this.map.clearRect(0, 0, window.innerWidth, window.innerHeight);
	// culling
	this.chunkCache
		.forEach((img, name) => { // check the bounds
			const coord = name.split('_', 2);
			if (this.isChunkWiseOnScreen(coord)) {
				// console.log('o');
				this.place(img, name);
			}
		});

	// gathering what we need to load
	const neededChunks = new Set();
	for (var x = Math.floor(this.x); x <= this.east; x++) {
		for (var y = Math.floor(this.y); y <= this.south; y++) {
			const name = x + '_' + y;
			
			// continue if its not available, or it is loaded
			if (!this.availableChunks.has(name) ||
				this.chunkCache.has(name)) continue;
			neededChunks.add(name);
		}
	}
	// iterating over everything we need to load
	const it = neededChunks.values();
	ViewFrame.intervalRef = setInterval(() => {
		let round = it.next();
		if (round.done) {
			clearInterval(ViewFrame.intervalRef);
			this.rendering = false;
			this.renderPoIs();
			return;
		}
		this.renderOneChunk(round.value);
		this.renderOneChunk(it.next().value);
	}, 10);
};

ViewFrame.prototype.renderOneChunk = function (name) {
	if (name === undefined) return;
	if (this.chunkCache.has(name)) {
		this.place(this.chunkCache.get(name), name);
	} else {
		// load
		const img = new Image(32, 32);
		img.src = `Chunks/${name}.png`;
		decode(img, () => {
			this.place(img, name);
			this.chunkCache.set(name, img);
		});
	}
};

ViewFrame.prototype.place = function (img, name) {
	let [chunkX, chunkY] = this.chunkWiseToScreen(name.split('_', 2));
	this.map.drawImage(img, Math.floor(chunkX), Math.floor(chunkY), this.zoom, this.zoom);
};

ViewFrame.prototype.renderPoIs = function () {
	ViewFrame.chunks.pointsOfInterest.forEach((poi, name) => {
		const loc = name.split('_', 2);
		const l = this.blockWiseToScreen(loc);
		if (this.isBlockWiseOnScreen(loc)) {
			this.renderOnePoI(poi, loc);
		}
	});
};

ViewFrame.prototype.renderOnePoI = function (poi, coord, color = 'red') {
	let [x, y] = this.blockWiseToScreen(coord);
	this.map.fillStyle = color;
	this.map.fillRect(x - 2, y - 2, 4, 4);
};

ViewFrame.prototype.updateInfobox = function (chunkName) {
	const chunkMeta = this.availableChunks.get(chunkName);
	if (chunkMeta === undefined) return;
	this.infoboxSlots.forEach((l, k) => {
		l.value = chunkMeta?.[k] ?? '??';
	});
};

ViewFrame.prototype.updateEoIbox = function (eoi) {
	const eoiMeta = ViewFrame.chunks.entityOfInterest.get(eoi);
	if (eoiMeta === undefined) return;
	this.entityInfoSlots.forEach((l, k) => {
		l.value = eoiMeta?.[k] ?? '??';
	});
};

ViewFrame.prototype.updatePoIbox = function (poi) {
	const poiMeta = ViewFrame.chunks.pointsOfInterest.get(poi);
	if (poiMeta === undefined) return;
	this.pointsInfoSlots.forEach((l, k) => {
		l.value = poiMeta?.[k] ?? '??';
	});
};